@@ -1,5 +1,6 @@
 from dateutil.relativedelta import relativedelta
 
+
 def vested(quantity, check_date, grant_date, vest_rate, vest_interval='m'):
     elapsed = relativedelta(check_date, grant_date)
     if elapsed.years >= 3:
@@ -10,7 +11,9 @@ def vested(quantity, check_date, grant_date, vest_rate, vest_interval='m'):
         v = int(elapsed.years * vest_rate * quantity)
     return (v, quantity - v)
 
-def vesting_profile(grant_quantity, grant_date, vesting_rate,
+
+def vesting_profile(
+        grant_quantity, grant_date, vesting_rate,
         profile_interval=relativedelta(months=+1)):
     d = grant_date
     p = []
